﻿namespace U2UConsult.EF4.Views.Sample
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// Demonstrates using an entity model based on [indexed] views.
    /// </summary>
    public class Program
    {
        /// <summary>
        /// Main entry point.
        /// </summary>
        /// <param name="args">Command line arguments</param>
        public static void Main(string[] args)
        {
            using (PersonEntities entities = new PersonEntities())
            {
                WriteTitle("Referential constraint: Person with Phones");

                Person person = (from p in entities.Person.Include("Phones")
                                 where p.PersonId == 1
                                 select p).FirstOrDefault();

                Console.WriteLine(" {0} {1}:", person.FirstName, person.LastName);
                foreach (var phone in person.Phones)
                {
                    Console.WriteLine("\t{0}", phone.PhoneNumber);
                }

                WriteTitle("Table mapping: Person with Addresses");

                person = (from p in entities.Person.Include("Addresses")
                          where p.PersonId == 2996
                          select p).FirstOrDefault();

                Console.WriteLine(" {0} {1}:", person.FirstName, person.LastName);
                foreach (var address in person.Addresses)
                {
                    Console.WriteLine("\t{0}, {1}", address.City, address.AddressLine1);
                }

                Console.ForegroundColor = ConsoleColor.Green;
                Console.WriteLine("\n\n\t\t\t(U2U Consult 2011)");

                Console.ReadKey();
            }
        }

        /// <summary>
        /// Writes a title on the console.
        /// </summary>
        /// <param name="title">Title text.</param>
        private static void WriteTitle(string title)
        {
            Console.ForegroundColor = ConsoleColor.Yellow;
            Console.WriteLine();
            Console.WriteLine(" {0}", title);
            Console.WriteLine(" {0}", new string('-', title.Length));
            Console.WriteLine();
            Console.ForegroundColor = ConsoleColor.White;
        }
    }
}
